<?php
class Coverflow_Carousel_Module extends ET_Builder_Module
{
	public function init()
	{
		parent::init();
		$this->name             = 'Coverflow Carousel';
		$this->version          = '1.0.7';
		$this->slug             = 'mw_coverflow_carousel';
		$this->fb_support       = 'partial';
		$this->use_row_content  = true;
		$this->main_css_element = '%%order_class%%';
		$this->advanced_fields  = $this->set_advanced_fields();
		$this->custom_css_fields = [];
	}

	public function set_advanced_fields(){
		$advanced_fields = [];
		$advanced_fields['border'] = [];
		$advanced_fields['animation'] = [];
		$advanced_fields['margin_padding'] = [
			'css'        => [
				'padding'   => "{$this->main_css_element} .slick-slide",
				'margin'    => "{$this->main_css_element} .slick-slide",
			],
		];
		$advanced_fields['background'] = [
			'css' => array(
				'main' => "{$this->main_css_element} .slick-slide",
			),
		];
		return $advanced_fields;
	}

	public function get_fields()
	{
		return [
			'gallery_ids'            => array(
				'label'            => esc_html__( 'Images', 'et_builder' ),
				'description'      => esc_html__( 'Choose the images that you would like to appear in the image gallery.', 'et_builder' ),
				'type'             => 'upload-gallery',
				'computed_affects' => array(
					'__gallery',
				),
				'option_category'  => 'basic_option',
				'toggle_slug'      => 'main_content',
			),
			'gallery_orderby'        => array(
				'label'            => esc_html__( 'Image Order', 'et_builder' ),
				'description'      => esc_html__( 'Select an ordering method for the gallery. This controls which gallery items appear first in the list.', 'et_builder' ),
				'type'             => $this->is_loading_bb_data() ? 'hidden' : 'select',
				'options'          => array(
					''     => et_builder_i18n( 'Default' ),
					'rand' => esc_html__( 'Random', 'et_builder' ),
				),
				'default'          => 'off',
				'class'            => array( 'et-pb-gallery-ids-field' ),
				'computed_affects' => array(
					'__gallery',
				),
				'toggle_slug'      => 'main_content',
			),
			'gallery_captions'       => array(
				'type'             => 'hidden',
				'class'            => array( 'et-pb-gallery-captions-field' ),
				'computed_affects' => array(
					'__gallery',
				),
			),
		];
	}

	public function render($atts, $content = NULL, $render_slug)
	{
		$atts = apply_filters( "{$this->slug}_module_atts", $this->props );
		$gallery_ids  = $this->props['gallery_ids'];
		$gallery_ids = explode(",", $gallery_ids);
		$gallery = '<div class="flipster"> <ul class="flip-items">';
		foreach($gallery_ids as $gallery_id){
			$image = wp_get_attachment_image ( $gallery_id, 'thumbnail' );
			$gallery .= '<li>'.$image.'</li>';
		}
		$gallery .= ' </ul></div>';
		$gallery_order = self::_get_index( array( self::INDEX_MODULE_ORDER, $render_slug ) );

		$output = sprintf(
			'<div %1$s class="%2$s"> %3$s </div>
			<script>
				jQuery(document).ready(function(){
					jQuery("%4$s .flipster").flipster({
					  autoplay: 1200,
					  style: "infinite-carousel",
					  loop: 2,
					  scrollwheel: false,
					  buttons: false
					});
				});
			</script>',
			$this->module_id(),
			$this->module_classname( $render_slug ),
			$gallery,
			".".$render_slug."_".$gallery_order
		);
		
		$current_directory_url = trailingslashit( wp_make_link_relative( get_template_directory_uri() . str_replace( get_template_directory(), '', __DIR__ ) ) );

		if (!is_admin()) {
			wp_enqueue_script('mw_coverflow_carousel', $current_directory_url.'mw_coverflow_carousel.js', ['jquery'], $this->version );
			wp_enqueue_style('mw_coverflow_carousel', $current_directory_url.'mw_coverflow_carousel.css', [], $this->version);
		}
		return $output;
	}
}
new Coverflow_Carousel_Module;